#
# spec file for package wp-cli
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           wp-cli
Version:        2.12.0
Release:        1.1
Summary:        WordPress command-line interface
License:        MIT
URL:            https://wp-cli.org/
Source0:        https://github.com/%{name}/%{name}/releases/download/v%{version}/%{name}-%{version}.phar
Source1:        https://raw.githubusercontent.com/%{name}/%{name}/v%{version}/utils/wp-completion.bash
Requires:       php >= 5.6
Requires:       php-json
Requires:       php-openssl
Requires:       php-phar
Requires:       php-zip
BuildArch:      noarch

%description
WP-CLI is the command-line interface for WordPress. You can update plugins,
configure multisite installations and much more, without using a web browser.

%prep
%autosetup -c -T

%build

%install
mkdir -p %{buildroot}%{_bindir}
install -m 0755 %{SOURCE0} %{buildroot}%{_bindir}/wp
mkdir -p %{buildroot}%{_sysconfdir}/profile.d
install -m 0644 %{SOURCE1} %{buildroot}%{_sysconfdir}/profile.d

%check

%files
%defattr(-,root,root,0755)
%{_bindir}/wp
%config %{_sysconfdir}/profile.d/wp-completion.bash

%changelog
* Wed May  7 2025 Andreas Schneider <asn@cryptomilk.org>
- Update to version 2.12.0
  * PHP 8.4 | Fix implicitly nullable parameters by @jrfnl in #5982
  * PHP 8.3 | ReportWidthTest: fix deprecation notices for
    ReflectionProperty::setValue() by @jrfnl in #5984
  * PHP 8.1 | WP_CLI\Iterators\CSV: fix "missing return type" deprecation
    warnings by @jrfnl in #5983
  * PHP 8.4 | wp_debug_mode(): remove use of E_STRICT by @jrfnl in #5986
  * PHP 8.4 | Update Requests to v 2.0.12 by @jrfnl in #5981
  * Remove unused automerge workflow by @swissspidy in #5992
  * Composer: prevent a lock file from being created by @swissspidy in #5993
  * Fix tests against WordPress trunk by @swissspidy in #5995
  * Skip Requests v1 test on PHP 8.2+ by @swissspidy in #5996
  * UtilsTest: fix the test failure by @jrfnl in #5997
  * PHPUnit: convert deprecations to exceptions by @swissspidy in #5994
  * PHP 8.4 | Fix CSV escaping deprecation notices by @jrfnl in #5991
  * Added global documentation by @wpeople-dev in #6017
  * Update wp-cli/php-cli-tools by @bor0 in #6021
  * Code quality improvements powered by PHPStan by @swissspidy in #6019
  * Fix: Update outdated AJAX documentation link by @PARTHVATALIYA in #6031
  * Update expected error message in unit tests by @swissspidy in #6032
  * Add hook to http_request() util by @swissspidy in #6036
  * Improve regex for detecting wp-settings.php by @swissspidy in #6039
  * Ensure code after wp-settings.php call is loaded by @swissspidy in #6042
  * Added PHPDoc for cmd_starts_with() method by @PARTHVATALIYA in #6034
  * Update log and warning logger functions comment according to the actual
    functionality by @matiasbenedetto in #5979
  * Add configurable user agent to WP-CLI to detect in firewall logs by
  @amirhmoradi in #5998
  * docker scheme: working-directory and stdin passing by @drzraf in #5974
  * Revert "docker scheme: working-directory and stdin passing" by @swissspidy
    in #6049
  * Allow collecting PHPUnit coverage by @swissspidy in #6041
  * Add defaults and accepted values for runcommand() options in doc by
    @i-am-chitti in #5953
  * Check PHP version requirement in update check by @swissspidy in #6037
  * docker scheme: working-directory and stdin passing (reroll of #5974) by
    @drzraf in #6057
  * Fix undefined variable issue by @swissspidy in #6058
  * Add test for line breaks in table view by @BhargavBhandari90 in #6055
  * Temporarily remove roave/security-advisories by @swissspidy in #6060
  * Improve command suggestions for taxonomies and post types by
    @karthick-murugan in #6059
  * Update wp-cli/php-cli-tools dependency by @swissspidy in #6061
  * Support multiple files in WP_CLI_EARLY_REQUIRE by @swissspidy in #6065
  * Removes array_column compatability function by @9ete in #6068
  * Properly create missing wp cli config file when needed. by @mrsdizzie in
  [#6062]
  * Add WP_CLI_REQUIRE env var for including extra php files by @mrsdizzie in
  [#6070]
  * Update WP-CLI update message by @wojsmol in #6071
  * Detect MariaDB vs MySQL by @swissspidy in #6072
  * Fix update step for nightlies by @swissspidy in #6075
  * Fix Gherkin lint issues by @swissspidy in #6076
  * Do not error if mysql binary not found by @swissspidy in #6077
  * Fix Gherkin lint issues by @ernilambar in #6082
  * Set display_errors to stderr (lowercase) instead of STDERR by @WPprodigy in
    [#6084]
  * don't forcefully exec() docker version by @drzraf in #6040
  * Update release issue templates by @swissspidy in #6078
  * Fix unstable package override tests by @swissspidy in #6069
  * allow remote binary customization by @drzraf in #6013
  * Make sure existing esc_like() takes precedence by @schlessera in #6088
  * Check for root earlier by @schlessera in #5987
  * Escape CSV output by @schlessera in #6089
  * Use forked mustache library by @swissspidy in #6090
  * Replace duplicate-post plugin with debug-bar in feature tests by @schlessera in #6091
  * Release v2.12.0 by @schlessera in #6092
* Mon Feb 10 2025 Andreas Schneider <asn@cryptomilk.org>
- Update to version 2.11.0
  * Allow manually dispatching tests workflow [#5965]
  * Add fish shell completion [#5954]
  * Add defaults and accepted values for runcommand() options in doc [#5953]
  * Address warnings with filenames ending in fullstop on Windows [#5951]
  * Fix unit tests [#5950]
  * Update copyright year in license [#5942]
  * Fix breaking multi-line CSV values on reading [#5939]
  * Fix broken Gutenberg test [#5938]
  * Update docker runner to resolve docker path using /usr/bin/env [#5936]
  * Fix inherit path in nested directory [#5930]
  * Minor docblock improvements [#5929]
  * Add Signup fetcher [#5926]
  * Ensure the alias has the leading @ symbol when added [#5924]
  * Include any non default hook information in CompositeCommand [#5921]
  * Correct completion case when ends in = [#5913]
  * Docs: Fixes for inline comments [#5912]
  * Update Inline comments [#5910]
  * Add a real-world example for wp cli has-command [#5908]
  * Fix typos [#5901]
  * Avoid PHP deprecation notices in PHP 8.1.x [#5899]
* Sun Apr  7 2024 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 2.10.0
  * Fix PHP deprecation warnings [#5897]
  * Only use --skip-column-statistics flag when available [#5895]
  * Handle unparseable tags gracefully [#5894]
  * WpOrgApi: allow specifying fields request param [#5893]
  * Remove unneeded compatibility shim [#5885]
  * Suggest 'network meta' intead of 'network option' [#5879]
  * Updated Doc Block for Admin.php [#5877]
  * Admin Context: Fix PHP fatals when admin.php has CRLF line endings [#5875]
  * Standard completion of current option [#5873]
  * Add WP_CLI\Utils\has_stdin() function [#5872]
  * Add verbosity level and quiet flag in ssh command based on debug flag [#5869]
  * Revert "Move RecursiveDataStructureTraverser to wp-cli/wp-cli package" [#5866]
  * Add missing required arguments when using --prompt [#5865]
  * Move RecursiveDataStructureTraverser to wp-cli/wp-cli package [#5864]
  * Add docker compose command support in SSH command generation [#5863]
  * Add missing documentation for $data attribute in http_request() [#5861]
  * Updated Inline PHP Documentation [#5853]
- Update to version 2.9.0
  * Add debugging output for @when command registration [#5841]
  * Fix --skip-themes for WordPress 6.4 [#5840]
  * Update phpcs.xml to match new WPCS rules [#5836]
  * Update to WPCS v3 [#5834]
  * Respect alias --path= in IncludeRequestsAutoloader [#5830]
  * Update type hint of $callable parameter in add_command() method [#5828]
  * Display a custom error message when themes/functions.php fatals [#5817]
  * Fix PHP 8.1 deprecation: ReturnTypeWillChange [#5807]
  * Add support for the proxyjump key [#5805]
  * Mention updating the homepage in the release process [#5802]
* Mon Jun 26 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 2.8.1
  * Define WP_CLI_ROOT if needed
  * Extract Requests out of Composer
- Update to version 2.8.0
  * Ignore Requests deprecations in error handling for now
  * Fallback to hardcoded folder when WPINC not defined
  * Conditionally adapt to Core Requests library
  * Add bootstrap step to extract default CA certificate
  * Use wp_cache_flush_runtime if supported.
  * Extract cacert from Phar for cURL
  * Fix some PHP 8.2 depreciation notices in behat tests
  * Upgrade WP-CLI to Requests v2
  * Added "wp cli alias is-group" subcommand.
  * Use -R instead of -r for fallback pager command
  * Fix autocompletion notice with PHP 8.2
  * fix PHP Deprecation for 8.1
  * Add composer phpcbf
  * Use WP_CLI_FORCE_USER_LOGIN=1 to force --user=<login>
  * Fix --skip-themes for themes with block patterns
  * Fix deprecation notice triggered in WpOrgApi class in PHP 8.1
  * Improve support for cases with empty --path provided to wp-cli commands
  * PHP 8.2: explicitly declare CompositeCommand::$longdesc to fix deprecation warning
  * Detect Object Cache Pro
  * Ensure WP_CLI_ROOT is defined before accessing it
* Tue Nov  8 2022 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 2.7.1
  * Avoid deleting TinyMCE themes/plugins by using more precise check
  * Support for docker-compose run
  * Customizable global parameters
  * Download WordPress Core files without extracting them
  * Directly install a specific locale
  * Clean duplicate meta values
  * Multiple changes to the i18n support
  * PHP 8.1 Support
  * New commands for managing application passwords
  * New global flag: --context
  * Configurable WP-CLI cache settings
  * Use custom names/locations for the wp-config.php file
  * Generate a dotenv file from your existing wp-config.php file
  * Allow plugin/theme enumeration without forcing an update check
  * New flag --strict for adapting the filtering of taxonomies by post type
* Sat Jul 10 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 2.5.0
  * Fix CVE-2021-29504: An improper error handling in HTTPS requests
    management in WP-CLI since version 0.12.0, allowing remote
    attackers able to intercept the communication to remotely disable
    the certificate verification on WP-CLI side
  * The security fix might break systems with invalid certificates,
    for old behavior "--insecure" flag was added
  * PHP 8 support
  * Improved MySQL/MariaDB support
  * Package Manager is now powered by Composer v2, speed improvements
  * New commands for managing automatic updates
  * New command for creating MO files
  * New environment variable: WP_CLI_ALLOW_ROOT
  * Support for third-party WP-CLI packages on GitLab
  * Full release notes:
    https://make.wordpress.org/cli/2021/05/19/wp-cli-v2-5-0-release-notes
* Mon Jan 13 2020 Matthias Fehring <buschmann23@opensuse.org>
- Version 2.4.0
  * Release notes: https://make.wordpress.org/cli/2019/11/12/wp-cli-v2-4-0-release-notes/
* Sun Nov  3 2019 Yunhe Guo <i@guoyunhe.me>
- Correct the URL of bash completion file
* Sun Nov  3 2019 Yunhe Guo <i@guoyunhe.me>
- Version 2.3.0
  * Release notes: https://make.wordpress.org/cli/2019/08/14/wp-cli-release-v2-3-0/
